==> kendo-ui-core-2020.2.715-internal.tgz: package/js/cultures/kendo.culture.sr-Latn-RS.js <==
module.exports =
/******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};

/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {

/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId])
/******/ 			return installedModules[moduleId].exports;

/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			exports: {},
/******/ 			id: moduleId,
/******/ 			loaded: false
/******/ 		};

/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);

/******/ 		// Flag the module as loaded
/******/ 		module.loaded = true;

/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}


/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;

/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;

/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";

/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(0);
/******/ })
/************************************************************************/
/******/ ({

/***/ 0:
/***/ (function(module, exports, __webpack_require__) {

	__webpack_require__(706);
	module.exports = __webpack_require__(706);


/***/ }),

/***/ 706:
/***/ (function(module, exports) {

	(function( window, undefined ) {
	    kendo.cultures["sr-Latn-RS"] = {
	        name: "sr-Latn-RS",
	        numberFormat: {
	            pattern: ["-n"],
	            decimals: 2,
	            ",": ".",
	            ".": ",",
	            groupSize: [3],
	            percent: {
	                pattern: ["-n%","n%"],
	                decimals: 2,
	                ",": ".",
	                ".": ",",
	                groupSize: [3],
	                symbol: "%"
	            },
	            currency: {
	                name: "Serbian Dinar",
	                abbr: "RSD",
	                pattern: ["-n $","n $"],
	                decimals: 0,
	                ",": ".",
	                ".": ",",
	                groupSize: [3],
	                symbol: "RSD"
	            }
	        },
	        calendars: {
	            standard: {
	                days: {
	                    names: ["nedelja","ponedeljak","utorak","sreda","četvrtak","petak","subota"],
	                    namesAbbr: ["ned","pon","uto","sre","čet","pet","sub"],
	                    namesShort: ["ned","pon","uto","sre","čet","pet","sub"]
	                },
	                months: {
	                    names: ["januar","februar","mart","april","maj","jun","jul","avgust","septembar","oktobar","novembar","decembar"],
	                    namesAbbr: ["jan","feb","mar","apr","maj","jun","jul","avg","sep","okt","nov","dec"]
	                },
	                AM: ["pre podne","pre podne","PRE PODNE"],
	                PM: ["po podne","po podne","PO PODNE"],
	                patterns: {
	                    d: "d.M.yyyy.",
	                    D: "dddd, dd. MMMM yyyy.",
	                    F: "dddd, dd. MMMM yyyy. HH.mm.ss",
	                    g: "d.M.yyyy. HH.mm",
	                    G: "d.M.yyyy. HH.mm.ss",
	                    m: "d. MMMM",
	                    M: "d. MMMM",
	                    s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
	                    t: "HH.mm",
	                    T: "HH.mm.ss",
	                    u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'",
	                    y: "MMMM yyyy.",
	                    Y: "MMMM yyyy."
	                },
	                "/": ".",
	                ":": ".",
	                firstDay: 1
	            }
	        }
	    }
	})(this);


/***/ })

/******/ });

==> kendo-ui-core-2021.2.519-internal.tgz: package/js/cultures/kendo.culture.sr-Latn-RS.js <==
module.exports =
/******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};

/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {

/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId])
/******/ 			return installedModules[moduleId].exports;

/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			exports: {},
/******/ 			id: moduleId,
/******/ 			loaded: false
/******/ 		};

/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);

/******/ 		// Flag the module as loaded
/******/ 		module.loaded = true;

/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}


/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;

/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;

/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";

/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(0);
/******/ })
/************************************************************************/
/******/ ({

/***/ 0:
/***/ (function(module, exports, __webpack_require__) {

	__webpack_require__(730);
	module.exports = __webpack_require__(730);


/***/ }),

/***/ 730:
/***/ (function(module, exports) {

	(function( window, undefined ) {
	    kendo.cultures["sr-Latn-RS"] = {
	        name: "sr-Latn-RS",
	        numberFormat: {
	            pattern: ["-n"],
	            decimals: 2,
	            ",": ".",
	            ".": ",",
	            groupSize: [3],
	            percent: {
	                pattern: ["-n%","n%"],
	                decimals: 2,
	                ",": ".",
	                ".": ",",
	                groupSize: [3],
	                symbol: "%"
	            },
	            currency: {
	                name: "Serbian Dinar",
	                abbr: "RSD",
	                pattern: ["-n $","n $"],
	                decimals: 0,
	                ",": ".",
	                ".": ",",
	                groupSize: [3],
	                symbol: "RSD"
	            }
	        },
	        calendars: {
	            standard: {
	                days: {
	                    names: ["nedelja","ponedeljak","utorak","sreda","četvrtak","petak","subota"],
	                    namesAbbr: ["ned","pon","uto","sre","čet","pet","sub"],
	                    namesShort: ["ne","po","ut","sr","če","pe","su"]
	                },
	                months: {
	                    names: ["januar","februar","mart","april","maj","jun","jul","avgust","septembar","oktobar","novembar","decembar"],
	                    namesAbbr: ["jan","feb","mar","apr","maj","jun","jul","avg","sep","okt","nov","dec"]
	                },
	                AM: ["pre podne","pre podne","PRE PODNE"],
	                PM: ["po podne","po podne","PO PODNE"],
	                patterns: {
	                    d: "d.M.yyyy.",
	                    D: "dddd, dd. MMMM yyyy.",
	                    F: "dddd, dd. MMMM yyyy. HH:mm:ss",
	                    g: "d.M.yyyy. HH:mm",
	                    G: "d.M.yyyy. HH:mm:ss",
	                    m: "d. MMMM",
	                    M: "d. MMMM",
	                    s: "yyyy'-'MM'-'dd'T'HH':'mm':'ss",
	                    t: "HH:mm",
	                    T: "HH:mm:ss",
	                    u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'",
	                    y: "MMMM yyyy.",
	                    Y: "MMMM yyyy."
	                },
	                "/": ".",
	                ":": ":",
	                firstDay: 1
	            }
	        }
	    }
	})(this);


/***/ })

/******/ });
